==> deepin-terminal_5.4.33.orig.tar.xz: deepin-terminal-5.4.33/3rdparty/terminalwidget/lib/translations/terminalwidget_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>Boyut: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>Boyut: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3178"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Çıktı &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;askıya alındı&lt;/a&gt; Ctrl+S tuşlarına basarak.  Bas &lt;b&gt;Ctrl+Q&lt;/b&gt; devam et.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1105"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Klavye tercümanı yok.  Tuşa basmaları uçbirime göndermek ve karakterlere dönüştürmek için gereken bilgiler eksik.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>İsimsiz Renk Düzeni</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>Erişilebilir Renk Düzeni</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="538"/>
        <source>Open link</source>
        <translation>Bağlantıyı aç</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="539"/>
        <source>Copy link</source>
        <translation>Bağlantıyı kopyala</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="543"/>
        <source>Send email to...</source>
        <translation>E-posta gönder...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="544"/>
        <source>Copy email address</source>
        <translation>E-posta adresini kopyala</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="451"/>
        <source>Color Scheme Error</source>
        <translation>Renk Düzeni Hatası</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="452"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Renk şeması yüklenemiyor: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Durum eşleşmesi</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Düzenli ifade</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Tüm eşleşmeleri vurgula</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>AramaÇubuğu</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Bul:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>

==> deepin-terminal_5.9.40+dfsg.orig.tar.xz: deepin-terminal-5.9.40/3rdparty/terminalwidget/lib/translations/terminalwidget_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>Boyut: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>Boyut: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3178"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Çıktı &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;askıya alındı&lt;/a&gt; Ctrl+S tuşlarına basarak.  Bas &lt;b&gt;Ctrl+Q&lt;/b&gt; devam et.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1105"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Klavye tercümanı yok.  Tuşa basmaları uçbirime göndermek ve karakterlere dönüştürmek için gereken bilgiler eksik.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>İsimsiz Renk Düzeni</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>Erişilebilir Renk Düzeni</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="538"/>
        <source>Open link</source>
        <translation>Bağlantıyı aç</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="539"/>
        <source>Copy link</source>
        <translation>Bağlantıyı kopyala</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="543"/>
        <source>Send email to...</source>
        <translation>E-posta gönder...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="544"/>
        <source>Copy email address</source>
        <translation>E-posta adresini kopyala</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="451"/>
        <source>Color Scheme Error</source>
        <translation>Renk Düzeni Hatası</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="452"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Renk şeması yüklenemiyor: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Durum eşleşmesi</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Düzenli ifade</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Tüm eşleşmeleri vurgula</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>AramaÇubuğu</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Bul:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
